@@ -208,7 +208,7 @@ class PlatformJson(pydantic.BaseModel):
         logger.info('Updating %s %s: %s -> %s', self.path.name, field, existing, new)
         setattr(self, field, new)
     
-def update_platform_json_fields(pj: PlatformJson, session) -> None:
+def update_from_session(pj: PlatformJson, session) -> None:
     "Updates fields in a platform json file."
     
     with pj.write_disabled():
