@@ -229,8 +229,10 @@ class Session:
     @property
     def npexp_path(self) -> pathlib.Path:
         """np-exp root / folder (may not exist)"""
-        return NPEXP_ROOT / self.folder
-
+        with contextlib.suppress(AttributeError):
+            return self._npexp_path    
+        self._npexp_path = NPEXP_ROOT / self.folder
+        return self.npexp_path
     @property
     def lims_path(self) -> pathlib.Path | None:
         """Corresponding directory in lims, if one can be found"""
